/*
  hostdef.h - Garage Shutter Controller Host Interface Define's

  Copyright (c) 2022 Sasapea's Lab. All right reserved.

  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Lesser General Public
  License as published by the Free Software Foundation; either
  version 2.1 of the License, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Lesser General Public License for more details.

  You should have received a copy of the GNU Lesser General
  Public License along with this library; if not, write to the
  Free Software Foundation, Inc., 59 Temple Place, Suite 330,
  Boston, MA  02111-1307  USA
*/
#pragma once

#include <stdint.h>

enum
{
  SHUTTER_SETTING = 0x00,
  SHUTTER_STOP    = 0x01,
  SHUTTER_DOWN    = 0x02,
  SHUTTER_UP      = 0x03,
  SHUTTER_AUTO_UP = 0x04,
  SHUTTER_PAUSE   = 0x05,
  SHUTTER_RESUME  = 0x06,
  SHUTTER_ALARM   = 0x07,
  BRIDGE_CONNECT  = 0x72,
  BRIDGE_POLLING  = 0x73,
  DEVICE_PAIRING  = 0x7E,
  DEVICE_RESET    = 0x7F,
};

enum
{
  PAIRING_DOWN,
  PAIRING_UP,
  PAIRING_AUTOUP,
  PAIRING_UPDOWN,
};

typedef struct
{
  uint8_t data[8];
} macaddr_t;

typedef struct __attribute__((packed))
{
  uint32_t pulse_time;
  uint32_t pulse_interval;
  uint32_t open_init;
  uint32_t open_time;
  uint32_t resume_time;
  uint32_t autodw_time;
  uint32_t alarm_disable;
} setting_t;

typedef struct __attribute__((packed))
{
  uint8_t command;
  union
  {
    uint8_t   data[255];
    setting_t setting;
    struct
    {
      macaddr_t mac;
      uint8_t  addrH;
      uint8_t  addrL;
    } address;
    struct
    {
      macaddr_t mac;
      macaddr_t self;
      uint8_t   ctrl;
    } pairing;
  } args;
} command_t;

