#!/bin/sh

INSTALL_DIR=$(cd $(dirname $0) && pwd)

PROGRAM_NAME=shutter
PROGRAM_PATH=${INSTALL_DIR}/${PROGRAM_NAME}
PROGRAM_OPTS=">/dev/null 2>&1"
SERVICE_NAME=${PROGRAM_NAME}
SERVICE_PATH=/etc/systemd/system/${SERVICE_NAME}.service
AVAHI_SERVICE_PATH=/etc/avahi/services/mqtt.service
MOSQUITTO_VERSION=2.0.15

apt install -y mosquitto

wget http://mosquitto.org/files/source/mosquitto-${MOSQUITTO_VERSION}.tar.gz
tar zxvf mosquitto-${MOSQUITTO_VERSION}.tar.gz
rm mosquitto-${MOSQUITTO_VERSION}.tar.gz
cd mosquitto-${MOSQUITTO_VERSION}
sed -i 's/WITH_CJSON:=yes/WITH_CJSON:=no/g' config.mk
#sed -i 's/WITH_STATIC_LIBRARIES:=no/WITH_STATIC_LIBRARIES:=yes/g' config.mk
#sed -i 's/WITH_SHARED_LIBRARIES:=yes/WITH_SHARED_LIBRARIES:=no/g' config.mk
make
make install  # installation puts .h files in /usr/local/include and library in /usr/local/lib
ldconfig      # Update /etc/ld.so.cache with the new library files in /usr/local/lib
cd ${INSTALL_DIR}

echo "#!/bin/sh" >${PROGRAM_PATH}.sh
echo >>${PROGRAM_PATH}.sh
echo "if [ -c /dev/ttyUSB0 ]; then" >>${PROGRAM_PATH}.sh
echo "  ${PROGRAM_PATH} -device ttyUSB0 ${PROGRAM_OPTS}" >>${PROGRAM_PATH}.sh
echo "elif [ -c /dev/ttyUSB1 ]; then" >>${PROGRAM_PATH}.sh
echo "  ${PROGRAM_PATH} -device ttyUSB1 ${PROGRAM_OPTS}" >>${PROGRAM_PATH}.sh
echo "fi" >>${PROGRAM_PATH}.sh
chmod +x ${PROGRAM_PATH}.sh

if [ -f ${SERVICE_PATH} ]; then
  systemctl stop ${SERVICE_NAME}
  systemctl disable ${SERVICE_NAME}
fi

echo "[Unit]" >${SERVICE_PATH}
echo "Description = Garage Shutter Controller" >>${SERVICE_PATH}
echo "After=multi-user.target" >>${SERVICE_PATH}
echo "ConditionPathExists=${INSTALL_DIR}" >>${SERVICE_PATH}
echo >>${SERVICE_PATH}
echo "[Service]" >>${SERVICE_PATH}
echo "ExecStart=${PROGRAM_PATH}.sh" >>${SERVICE_PATH}
echo "Restart=always" >>${SERVICE_PATH}
echo "Type=simple" >>${SERVICE_PATH}
echo >>${SERVICE_PATH}
echo "[Install]" >>${SERVICE_PATH}
echo "WantedBy=multi-user.target" >>${SERVICE_PATH}

systemctl daemon-reload
systemctl enable ${SERVICE_NAME}
systemctl start ${SERVICE_NAME}

#echo '<?xml version="1.0" standalone="no"?>' >${AVAHI_SERVICE_PATH}
#echo '<!DOCTYPE service-group SYSTEM "avahi-service.dtd">' >>${AVAHI_SERVICE_PATH}
#echo '<service-group>' >>${AVAHI_SERVICE_PATH}
#echo '  <name replace-wildcards="yes">%h</name>' >>${AVAHI_SERVICE_PATH}
#echo '  <service>' >>${AVAHI_SERVICE_PATH}
#echo '    <type>_mqtt._tcp</type>' >>${AVAHI_SERVICE_PATH}
#echo '    <port>1883</port>' >>${AVAHI_SERVICE_PATH}
#echo '  </service>' >>${AVAHI_SERVICE_PATH}
#echo '</service-group>' >>${AVAHI_SERVICE_PATH}

UTILTY_FILE=~/mqtt.sh
echo '#!/bin/sh' >${UTILTY_FILE}
echo >>${UTILTY_FILE}
echo 'logtime /var/log/mosquitto/mosquitto.log' >>${UTILTY_FILE}
chmod +x ${UTILTY_FILE}

UTILTY_FILE=~/shutter.sh
echo '#! /bin/sh' >${UTILTY_FILE}
echo >>${UTILTY_FILE}
echo 'if [ -f /var/log.hdd/syslog.1 ]; then' >>${UTILTY_FILE}
echo '  cat /var/log.hdd/syslog.1 | grep shutter' >>${UTILTY_FILE}
echo 'fi' >>${UTILTY_FILE}
echo 'cat /var/log/syslog | grep shutter' >>${UTILTY_FILE}
chmod +x ${UTILTY_FILE}
